==> apache-devlake-0.17.0-incubating-src.tar.gz: apache-devlake-0.17.0-incubating-src/backend/plugins/bitbucket/models/migrationscripts/archived/transformation_rule.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package archived

import (
	"github.com/apache/incubator-devlake/core/models/migrationscripts/archived"
	"gorm.io/datatypes"
)

type BitbucketTransformationRule struct {
	archived.Model
	Name              string            `gorm:"type:varchar(255);index:idx_name_github,unique"`
	DeploymentPattern string            `gorm:"type:varchar(255)"`
	ProductionPattern string            `gorm:"type:varchar(255)"`
	Refdiff           datatypes.JSONMap `format:"json"`

	// a string array, split by `,`.
	IssueStatusTodo       string `gorm:"type:varchar(255)"`
	IssueStatusInProgress string `gorm:"type:varchar(255)"`
	IssueStatusDone       string `gorm:"type:varchar(255)"`
	IssueStatusOther      string `gorm:"type:varchar(255)"`
}

func (BitbucketTransformationRule) TableName() string {
	return "_tool_bitbucket_transformation_rules"
}

==> apache-devlake-1.0.2-incubating-src.tar.gz: apache-devlake-1.0.2-incubating-src/backend/plugins/bitbucket/models/migrationscripts/archived/transformation_rule.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package archived

import (
	"encoding/json"

	"github.com/apache/incubator-devlake/core/models/migrationscripts/archived"
)

type BitbucketTransformationRule struct {
	archived.Model
	Name              string          `gorm:"type:varchar(255);index:idx_name_github,unique"`
	DeploymentPattern string          `gorm:"type:varchar(255)"`
	ProductionPattern string          `gorm:"type:varchar(255)"`
	Refdiff           json.RawMessage `gorm:"type:json"`

	// a string array, split by `,`.
	IssueStatusTodo       string `gorm:"type:varchar(255)"`
	IssueStatusInProgress string `gorm:"type:varchar(255)"`
	IssueStatusDone       string `gorm:"type:varchar(255)"`
	IssueStatusOther      string `gorm:"type:varchar(255)"`
}

func (BitbucketTransformationRule) TableName() string {
	return "_tool_bitbucket_transformation_rules"
}
